@@ -1,5 +1,5 @@
 /* dom.h
- * $Id: dom.h 597 2006-09-21 22:25:25Z pajas $
+ * $Id$
  * Author: Christian Glahn (2001)
  * 
  * This header file provides some definitions for wrapper functions.
@@ -20,8 +20,30 @@
 #ifndef __LIBXML_DOM_H__
 #define __LIBXML_DOM_H__
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+#include "EXTERN.h"
+#include "perl.h"
+#include "XSUB.h"
+#include "ppport.h"
+
 #include <libxml/tree.h>
 #include <libxml/xpath.h>
+#include <libxml/encoding.h>
+#include <libxml/xmlerror.h>
+#include <libxml/xmlmemory.h>
+#include <libxml/parser.h>
+#include <libxml/parserInternals.h>
+#include <libxml/xmlIO.h>
+#include <libxml/xpathInternals.h>
+#include <libxml/globals.h>
+#include <stdio.h>
+
+#ifdef __cplusplus
+}
+#endif
 
 /**
  * part 0:
@@ -29,6 +51,8 @@
  * unsortet. 
  **/
 
+void
+domReconcileNs(xmlNodePtr tree);
 
 /**
  * NAME domParseChar
@@ -86,7 +110,7 @@ domIsParent( xmlNodePtr cur, xmlNodePtr ref );
  * NAME domTestHierarchy
  * TYPE function
  *
- * tests the general hierachy error
+ * tests the general hierarchy error
  *
  * SYNOPSIS
  * if ( domTestHierarchy(cur, ref) ) ...
@@ -188,9 +212,6 @@ domGetNodeValue( xmlNodePtr self );
 void
 domSetNodeValue( xmlNodePtr self, xmlChar* value );
 
-void
-domSetParentNode( xmlNodePtr self, xmlNodePtr newParent );
-
 xmlNodePtr
 domReplaceNode( xmlNodePtr old, xmlNodePtr new );
 
@@ -204,7 +225,7 @@ domReplaceNode( xmlNodePtr old, xmlNodePtr new );
  * NAME domImportNode
  * TYPE function
  * SYNOPSIS
- * node = domImportNode( document, node, move);#
+ * node = domImportNode( document, node, move, reconcileNS);
  *
  * the function will import a node to the given document. it will work safe
  * with namespaces and subtrees. 
@@ -213,11 +234,13 @@ domReplaceNode( xmlNodePtr old, xmlNodePtr new );
  * original document. if move is set to 0, the node will be copied with the 
  * deep option. 
  *
+ * if reconcileNS is 1, namespaces are reconciled.
+ *
  * the function will return the imported node on success. otherwise NULL
  * is returned 
  */
 xmlNodePtr
-domImportNode( xmlDocPtr document, xmlNodePtr node, int move );
+domImportNode( xmlDocPtr document, xmlNodePtr node, int move, int reconcileNS );
 
 /**
  * part C:
@@ -249,4 +272,10 @@ domNodeNormalizeList( xmlNodePtr nodelist );
 int
 domRemoveNsRefs(xmlNodePtr tree, xmlNsPtr ns);
 
+void
+domAttrSerializeContent(xmlBufferPtr buffer, xmlAttrPtr attr);
+
+void
+domClearPSVI(xmlNodePtr tree);
+
 #endif
