@@ -28,8 +28,8 @@ use overload
   },
   fallback => 1;
 
-$WARNINGS = 0; # 0: supress, 1: report via warn, 2: report via die
-$VERSION = "2.0001"; # VERSION TEMPLATE: DO NOT CHANGE
+$WARNINGS = 0; # 0: suppress, 1: report via warn, 2: report via die
+$VERSION = "2.0002"; # VERSION TEMPLATE: DO NOT CHANGE
 
 use constant XML_ERR_NONE            => 0;
 use constant XML_ERR_WARNING         => 1; # A simple warning
